@@ -26,21 +26,6 @@
 #include <sys/stat.h>
 #include <unistd.h>
 
-/* Quick hack so I can mark strings */
-
-#ifdef _ 
-#warning "_ already defined"
-#else
-#define _(x) x
-#endif
-
-#ifdef N_ 
-#warning "N_ already defined"
-#else
-#define N_(x) x
-#endif
-
-
 gchar* 
 gconf_address_backend(const gchar* address)
 {
@@ -160,10 +145,12 @@ gconf_backend_file(const gchar* address)
   else
     {
       /* -- debug only */
+#ifdef GCONF_ENABLE_DEBUG      
       gchar* dir;
 
       g_free(retval);
-      dir = g_strconcat(GCONF_BUILDDIR, "/backends/.libs", NULL);
+      dir = g_strconcat(GCONF_SRCDIR, "/gconf/",
+                        GCONF_BUILDDIR, "/backends/.libs", NULL);
 
       retval = g_module_build_path(dir, file);
 
@@ -174,7 +161,7 @@ gconf_backend_file(const gchar* address)
           g_free(file);
           return retval;
         }
-
+#endif
       /* -- end debug only */
 
       gconf_log(GCL_ERR, _("No such file `%s'\n"), retval);
@@ -192,7 +179,7 @@ gconf_backend_file(const gchar* address)
 static GHashTable* loaded_backends = NULL;
 
 GConfBackend* 
-gconf_get_backend(const gchar* address, GConfError** err)
+gconf_get_backend(const gchar* address, GError** err)
 {
   GConfBackend* backend;
   gchar* name;
@@ -298,14 +285,14 @@ gconf_backend_unref(GConfBackend* backend)
     }
   else
     {
-      GConfError* error = NULL;
+      GError* error = NULL;
       
       (*backend->vtable->shutdown)(&error);
 
       if (error != NULL)
         {
-          g_warning(error->str);
-          gconf_error_destroy(error);
+          g_warning(error->message);
+          g_error_free(error);
         }
           
       if (!g_module_close(backend->module))
@@ -326,7 +313,7 @@ gconf_backend_unref(GConfBackend* backend)
 GConfSource*  
 gconf_backend_resolve_address (GConfBackend* backend, 
                                const gchar* address,
-                               GConfError** err)
+                               GError** err)
 {
   gchar** flags;
   gchar** iter;
