@@ -6,7 +6,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: PACKAGE VERSION\n"
-"POT-Creation-Date: 2001-08-15 18:01-0400\n"
+"POT-Creation-Date: 2001-10-12 20:08-0400\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: LANGUAGE <LL@li.org>\n"
@@ -32,7 +32,7 @@ msgstr ""
 msgid "Couldn't find the %s root directory in the address `%s'"
 msgstr ""
 
-#: backends/dir-utils.c:124 backends/xml-backend.c:301 backends/xml-dir.c:1051
+#: backends/dir-utils.c:124 backends/xml-backend.c:301 backends/xml-dir.c:1053
 #, c-format
 msgid "Could not make directory `%s': %s"
 msgstr ""
@@ -144,17 +144,17 @@ msgstr ""
 msgid "Entry with no name in XML file `%s', ignoring"
 msgstr ""
 
-#: backends/xml-dir.c:979
+#: backends/xml-dir.c:980
 #, c-format
-msgid "Toplevel node in XML file `%s' is not an <entry>, ignoring"
+msgid "A toplevel node in XML file `%s' is <%s> rather than <entry>, ignoring"
 msgstr ""
 
-#: backends/xml-dir.c:1067
+#: backends/xml-dir.c:1069
 #, c-format
 msgid "Failed to create file `%s': %s"
 msgstr ""
 
-#: backends/xml-dir.c:1075 gconf/gconf-internals.c:2494
+#: backends/xml-dir.c:1077
 #, c-format
 msgid "Failed to close file `%s': %s"
 msgstr ""
@@ -165,11 +165,6 @@ msgstr ""
 msgid "Ignoring XML node with name `%s': %s"
 msgstr ""
 
-#: backends/xml-entry.c:200
-#, c-format
-msgid "%s"
-msgstr ""
-
 #: backends/xml-entry.c:327
 #, c-format
 msgid "Ignoring schema name `%s', invalid: %s"
@@ -441,174 +436,268 @@ msgstr ""
 msgid "No database available to save your configuration"
 msgstr ""
 
-#: gconf/gconf-internals.c:87
+#: gconf/gconf-internals.c:112
 #, c-format
 msgid "No '/' in key `%s'"
 msgstr ""
 
-#: gconf/gconf-internals.c:251
+#: gconf/gconf-internals.c:225
+#, c-format
+msgid "Invalid UTF-8 in string value in '%s'"
+msgstr ""
+
+#: gconf/gconf-internals.c:284
 msgid "Couldn't interpret CORBA value for list element"
 msgstr ""
 
-#: gconf/gconf-internals.c:253
+#: gconf/gconf-internals.c:286
 #, c-format
 msgid "Incorrect type for list element in %s"
 msgstr ""
 
-#: gconf/gconf-internals.c:266
+#: gconf/gconf-internals.c:299
 msgid "Received list from gconfd with a bad list type"
 msgstr ""
 
-#: gconf/gconf-internals.c:447
+#: gconf/gconf-internals.c:480
 msgid "Failed to convert object to IOR"
 msgstr ""
 
-#: gconf/gconf-internals.c:813
+#: gconf/gconf-internals.c:617
+msgid "Invalid UTF-8 in locale for schema"
+msgstr ""
+
+#: gconf/gconf-internals.c:625
+msgid "Invalid UTF-8 in short description for schema"
+msgstr ""
+
+#: gconf/gconf-internals.c:633
+msgid "Invalid UTF-8 in long description for schema"
+msgstr ""
+
+#: gconf/gconf-internals.c:641
+msgid "Invalid UTF-8 in owner for schema"
+msgstr ""
+
+#: gconf/gconf-internals.c:866
 #, c-format
 msgid "Couldn't open path file `%s': %s\n"
 msgstr ""
 
-#: gconf/gconf-internals.c:873
+#: gconf/gconf-internals.c:926
 #, c-format
 msgid "Adding source `%s'\n"
 msgstr ""
 
-#: gconf/gconf-internals.c:885
+#: gconf/gconf-internals.c:938
 #, c-format
 msgid "Read error on file `%s': %s\n"
 msgstr ""
 
-#: gconf/gconf-internals.c:1327
+#: gconf/gconf-internals.c:1269 gconf/gconf-internals.c:1335
+#: gconf/gconf-value.c:125 gconf/gconf-value.c:224 gconf/gconf-value.c:366
+#: gconf/gconf-value.c:1084
+msgid "Text contains invalid UTF-8"
+msgstr ""
+
+#: gconf/gconf-internals.c:1420
 #, c-format
 msgid "Expected list, got %s"
 msgstr ""
 
-#: gconf/gconf-internals.c:1337
+#: gconf/gconf-internals.c:1430
 #, c-format
 msgid "Expected list of %s, got list of %s"
 msgstr ""
 
-#: gconf/gconf-internals.c:1476
+#: gconf/gconf-internals.c:1569
 #, c-format
 msgid "Expected pair, got %s"
 msgstr ""
 
-#: gconf/gconf-internals.c:1490
+#: gconf/gconf-internals.c:1583
 #, c-format
 msgid "Expected (%s,%s) pair, got a pair with one or both values missing"
 msgstr ""
 
-#: gconf/gconf-internals.c:1506
+#: gconf/gconf-internals.c:1599
 #, c-format
 msgid "Expected pair of type (%s,%s) got type (%s,%s)"
 msgstr ""
 
-#: gconf/gconf-internals.c:1622
+#: gconf/gconf-internals.c:1715
 msgid "Quoted string doesn't begin with a quotation mark"
 msgstr ""
 
-#: gconf/gconf-internals.c:1684
+#: gconf/gconf-internals.c:1777
 msgid "Quoted string doesn't end with a quotation mark"
 msgstr ""
 
-#: gconf/gconf-internals.c:2164 gconf/gconf.c:3092
+#: gconf/gconf-internals.c:1913
+msgid "Encoded value is not valid UTF-8"
+msgstr ""
+
+#: gconf/gconf-internals.c:2263 gconf/gconf.c:3082
 #, c-format
 msgid "CORBA error: %s"
 msgstr ""
 
-#: gconf/gconf-internals.c:2180
+#: gconf/gconf-internals.c:2279
 #, c-format
 msgid "OAF problem description: '%s'"
 msgstr ""
 
-#: gconf/gconf-internals.c:2186
+#: gconf/gconf-internals.c:2285
 msgid "attempt to remove not-listed OAF object directory"
 msgstr ""
 
-#: gconf/gconf-internals.c:2191
+#: gconf/gconf-internals.c:2290
 msgid "attempt to add already-listed OAF directory"
 msgstr ""
 
-#: gconf/gconf-internals.c:2198
+#: gconf/gconf-internals.c:2297
 #, c-format
 msgid "OAF parse error: %s"
 msgstr ""
 
-#: gconf/gconf-internals.c:2203
+#: gconf/gconf-internals.c:2302
 msgid "Unknown OAF error"
 msgstr ""
 
-#: gconf/gconf-internals.c:2290
+#: gconf/gconf-internals.c:2435
 #, c-format
-msgid "No ior file in `%s'"
+msgid "Could not lock temporary file '%s': %s"
 msgstr ""
 
-#: gconf/gconf-internals.c:2321
+#: gconf/gconf-internals.c:2462
 #, c-format
-msgid "gconfd taking lock `%s' from some other process"
+msgid "Could not create file '%s', probably because it already exists"
 msgstr ""
 
-#: gconf/gconf-internals.c:2332
+#: gconf/gconf-internals.c:2508
 #, c-format
-msgid "Another program has lock `%s'"
+msgid "Failed to create or open '%s'"
 msgstr ""
 
-#: gconf/gconf-internals.c:2351
-msgid "couldn't contact ORB to ping existing gconfd"
+#: gconf/gconf-internals.c:2518
+#, c-format
+msgid "Failed to lock '%s': another process has the lock (%s)"
 msgstr ""
 
-#: gconf/gconf-internals.c:2359
+#: gconf/gconf-internals.c:2546
 #, c-format
-msgid ""
-"Removing stale lock `%s' because IOR couldn't be converted to object "
-"reference, IOR `%s'"
-msgstr ""
-
-#: gconf/gconf-internals.c:2371
-#, c-format
-msgid "Removing stale lock `%s' because of error pinging server: %s"
-msgstr ""
-
-#: gconf/gconf-internals.c:2383
-#, c-format
-msgid "GConf configuration daemon (gconfd) has lock `%s'"
-msgstr ""
-
-#: gconf/gconf-internals.c:2397
-#, c-format
-msgid "couldn't create directory `%s': %s"
-msgstr ""
-
-#: gconf/gconf-internals.c:2446
-#, c-format
-msgid "Can't create lock `%s': %s"
-msgstr ""
-
-#: gconf/gconf-internals.c:2482
-#, c-format
-msgid "Can't write to file `%s': %s"
-msgstr ""
-
-#: gconf/gconf-internals.c:2532
-#, c-format
-msgid "Can't open lock file `%s'; assuming it isn't ours: %s"
-msgstr ""
-
-#: gconf/gconf-internals.c:2549
-#, c-format
-msgid "Corrupt lock file `%s', removing anyway"
-msgstr ""
-
-#: gconf/gconf-internals.c:2559
-#, c-format
-msgid ""
-"Didn't create lock file `%s' (creator pid %u, our pid %u; assuming someone "
-"took our lock"
+msgid "IOR file '%s' not opened successfully, no gconfd located: %s"
 msgstr ""
 
 #: gconf/gconf-internals.c:2576
 #, c-format
-msgid "Failed to release lock directory `%s': %s"
+msgid "gconftool or other non-gconfd process has the lock file '%s'"
+msgstr ""
+
+#: gconf/gconf-internals.c:2593
+msgid "couldn't contact ORB to resolve existing gconfd object reference"
+msgstr ""
+
+#: gconf/gconf-internals.c:2625
+#, c-format
+msgid "couldn't create directory `%s': %s"
+msgstr ""
+
+#: gconf/gconf-internals.c:2684
+#, c-format
+msgid "Can't write to file `%s': %s"
+msgstr ""
+
+#: gconf/gconf-internals.c:2725
+#, c-format
+msgid "We didn't have the lock on file `%s', but we should have"
+msgstr ""
+
+#: gconf/gconf-internals.c:2746
+#, c-format
+msgid "Failed to link '%s' to '%s': %s"
+msgstr ""
+
+#: gconf/gconf-internals.c:2758
+#, c-format
+msgid "Failed to remove lock file `%s': %s"
+msgstr ""
+
+#: gconf/gconf-internals.c:2777
+#, c-format
+msgid "Failed to clean up file '%s': %s"
+msgstr ""
+
+#: gconf/gconf-internals.c:2791
+#, c-format
+msgid "Failed to remove lock directory `%s': %s"
+msgstr ""
+
+#: gconf/gconf-internals.c:3001 gconf/gconfd.c:578
+#, c-format
+msgid "Failed to create %s: %s"
+msgstr ""
+
+#: gconf/gconf-internals.c:3034
+#, c-format
+msgid "Failed to create pipe for communicating with spawned gconf daemon: %s\n"
+msgstr ""
+
+#: gconf/gconf-internals.c:3058
+#, c-format
+msgid "Failed to launch configuration server: %s\n"
+msgstr ""
+
+#: gconf/gconf-internals.c:3080
+msgid ""
+"Failed to contact configuration server (a likely cause of this is that you "
+"have an existing configuration server (gconfd) running, but it isn't "
+"reachable from here - if you're logged in from two machines at once, you may "
+"need to enable TCP networking for ORBit)\n"
+msgstr ""
+
+#: gconf/gconf-internals.c:3717
+#, c-format
+msgid "Failed to read from child pipe (%s)"
+msgstr ""
+
+#: gconf/gconf-internals.c:3782
+#, c-format
+msgid "Failed to fork (%s)"
+msgstr ""
+
+#: gconf/gconf-internals.c:3922
+#, c-format
+msgid "Failed to change to directory '%s' (%s)"
+msgstr ""
+
+#: gconf/gconf-internals.c:3932
+#, c-format
+msgid "Failed to execute child process (%s)"
+msgstr ""
+
+#: gconf/gconf-internals.c:3941
+#, c-format
+msgid "Failed to redirect output or input of child process (%s)"
+msgstr ""
+
+#: gconf/gconf-internals.c:3950
+#, c-format
+msgid "Failed to fork child process (%s)"
+msgstr ""
+
+#: gconf/gconf-internals.c:3958
+msgid "Unknown error executing child process"
+msgstr ""
+
+#: gconf/gconf-internals.c:3979
+#, c-format
+msgid "Failed to read enough data from child pid pipe (%s)"
+msgstr ""
+
+#: gconf/gconf-internals.c:4029
+#, c-format
+msgid "Failed to create pipe for communicating with child process (%s)"
 msgstr ""
 
 #: gconf/gconf-sources.c:320
@@ -638,10 +727,12 @@ msgid ""
 "Unable to store a value at key '%s', as the configuration server has no "
 "writeable databases. There are two common causes of this problem: 1) your "
 "configuration path file doesn't contain any databases or wasn't found or 2) "
-"OAF mistakenly created two gconfd processes. If you have two gconfd "
-"processes (or had two at the time the second was launched), then it's an OAF "
-"bug, not a GConf issue. Logging out, killing oafd and gconfd, and logging "
-"back in may help. As always, check the user.* syslog for details on problems "
+"somehow we mistakenly created two gconfd processes. If you have two gconfd "
+"processes (or had two at the time the second was launched), logging out, "
+"killing all copies of gconfd, and logging back in may help. Perhaps the "
+"problem is that you attempted to use GConf from two machines at once, and "
+"ORBit still has its default configuration that prevents remote CORBA "
+"connections? As always, check the user.* syslog for details on problems "
 "gconfd encountered."
 msgstr ""
 
@@ -660,62 +751,62 @@ msgstr ""
 msgid "Key `%s' listed as schema for key `%s' actually stores type `%s'"
 msgstr ""
 
-#: gconf/gconf-value.c:82
+#: gconf/gconf-value.c:81
 #, c-format
 msgid "Didn't understand `%s' (expected integer)"
 msgstr ""
 
-#: gconf/gconf-value.c:92
+#: gconf/gconf-value.c:91
 #, c-format
 msgid "Integer `%s' is too large or small"
 msgstr ""
 
-#: gconf/gconf-value.c:113
+#: gconf/gconf-value.c:112
 #, c-format
 msgid "Didn't understand `%s' (expected real number)"
 msgstr ""
 
-#: gconf/gconf-value.c:146
+#: gconf/gconf-value.c:156
 #, c-format
 msgid "Didn't understand `%s' (expected true or false)"
 msgstr ""
 
-#: gconf/gconf-value.c:214
+#: gconf/gconf-value.c:232
 #, c-format
 msgid "Didn't understand `%s' (list must start with a '[')"
 msgstr ""
 
-#: gconf/gconf-value.c:227
+#: gconf/gconf-value.c:245
 #, c-format
 msgid "Didn't understand `%s' (list must end with a ']')"
 msgstr ""
 
-#: gconf/gconf-value.c:278
+#: gconf/gconf-value.c:296
 #, c-format
 msgid "Didn't understand `%s' (extra unescaped ']' found inside list)"
 msgstr ""
 
-#: gconf/gconf-value.c:309 gconf/gconf-value.c:462
+#: gconf/gconf-value.c:327 gconf/gconf-value.c:488
 #, c-format
 msgid "Didn't understand `%s' (extra trailing characters)"
 msgstr ""
 
-#: gconf/gconf-value.c:348
+#: gconf/gconf-value.c:374
 #, c-format
 msgid "Didn't understand `%s' (pair must start with a '(')"
 msgstr ""
 
-#: gconf/gconf-value.c:361
+#: gconf/gconf-value.c:387
 #, c-format
 msgid "Didn't understand `%s' (pair must end with a ')')"
 msgstr ""
 
-#: gconf/gconf-value.c:391 gconf/gconf-value.c:477
+#: gconf/gconf-value.c:417 gconf/gconf-value.c:503
 #, c-format
 msgid "Didn't understand `%s' (wrong number of elements)"
 msgstr ""
 
-#: gconf/gconf-value.c:431
+#: gconf/gconf-value.c:457
 #, c-format
 msgid "Didn't understand `%s' (extra unescaped ')' found inside pair)"
 msgstr ""
@@ -725,322 +816,268 @@ msgstr ""
 msgid "`%s': %s"
 msgstr ""
 
-#: gconf/gconf.c:289
+#: gconf/gconf.c:287
 #, c-format
 msgid "Server couldn't resolve the address `%s'"
 msgstr ""
 
-#: gconf/gconf.c:574
+#: gconf/gconf.c:572
 msgid "Can't add notifications to a local configuration source"
 msgstr ""
 
-#: gconf/gconf.c:1870
+#: gconf/gconf.c:1868
 #, c-format
 msgid "Adding client to server's list failed, CORBA error: %s"
 msgstr ""
 
-#: gconf/gconf.c:1887
-msgid ""
-"Error contacting configuration server: OAF returned nil from "
-"oaf_activate_from_id() and did not set an exception explaining the problem. "
-"This is a bug in the OAF package; something went wrong in OAF, and no error "
-"was reported. This is not a bug in the GConf package. Do not report a GConf "
-"bug unless you have information indicating what went wrong with OAF that was "
-"caused by GConf."
-msgstr ""
-
-#: gconf/gconf.c:2198
+#: gconf/gconf.c:2183
 msgid "Failed to init GConf, exiting\n"
 msgstr ""
 
-#: gconf/gconf.c:2235
+#: gconf/gconf.c:2220
 msgid "Must begin with a slash (/)"
 msgstr ""
 
-#: gconf/gconf.c:2257
+#: gconf/gconf.c:2242
 msgid "Can't have two slashes (/) in a row"
 msgstr ""
 
-#: gconf/gconf.c:2259
+#: gconf/gconf.c:2244
 msgid "Can't have a period (.) right after a slash (/)"
 msgstr ""
 
-#: gconf/gconf.c:2280
+#: gconf/gconf.c:2265
 #, c-format
 msgid "`%c' is an invalid character in key/directory names"
 msgstr ""
 
-#: gconf/gconf.c:2294
+#: gconf/gconf.c:2279
 msgid "Key/directory may not end with a slash (/)"
 msgstr ""
 
-#: gconf/gconf.c:2547
+#: gconf/gconf.c:2520
 #, c-format
 msgid "Failure shutting down config server: %s"
 msgstr ""
 
-#: gconf/gconf.c:2608
+#: gconf/gconf.c:2581
 #, c-format
 msgid "Expected float, got %s"
 msgstr ""
 
-#: gconf/gconf.c:2643
+#: gconf/gconf.c:2616
 #, c-format
 msgid "Expected int, got %s"
 msgstr ""
 
-#: gconf/gconf.c:2678
+#: gconf/gconf.c:2651
 #, c-format
 msgid "Expected string, got %s"
 msgstr ""
 
-#: gconf/gconf.c:2715
+#: gconf/gconf.c:2688
 #, c-format
 msgid "Expected bool, got %s"
 msgstr ""
 
-#: gconf/gconf.c:2748
+#: gconf/gconf.c:2721
 #, c-format
 msgid "Expected schema, got %s"
 msgstr ""
 
-#: gconf/gconfd.c:248
+#: gconf/gconfd.c:247
 msgid "Shutdown request received"
 msgstr ""
 
-#: gconf/gconfd.c:280
+#: gconf/gconfd.c:279
 msgid ""
 "gconfd compiled with debugging; trying to load gconf.path from the source "
 "directory"
 msgstr ""
 
-#: gconf/gconfd.c:298
+#: gconf/gconfd.c:297
 #, c-format
 msgid ""
 "No configuration files found, trying to use the default config source `%s'"
 msgstr ""
 
-#: gconf/gconfd.c:307
+#: gconf/gconfd.c:306
 msgid ""
 "No configuration sources in the source path, configuration won't be saved; "
 "edit "
 msgstr ""
 
-#: gconf/gconfd.c:307
+#: gconf/gconfd.c:306
 msgid "/path"
 msgstr ""
 
-#: gconf/gconfd.c:321
+#: gconf/gconfd.c:320
 #, c-format
 msgid "Error loading some config sources: %s"
 msgstr ""
 
-#: gconf/gconfd.c:333
+#: gconf/gconfd.c:332
 msgid ""
 "No config source addresses successfully resolved, can't load or store config "
 "data"
 msgstr ""
 
-#: gconf/gconfd.c:350
+#: gconf/gconfd.c:349
 msgid ""
 "No writable config sources successfully resolved, may not be able to save "
 "some configuration changes"
 msgstr ""
 
-#: gconf/gconfd.c:376
+#: gconf/gconfd.c:375
 #, c-format
 msgid "Received signal %d, dumping core. Please report a GConf bug."
 msgstr ""
 
-#: gconf/gconfd.c:392
+#: gconf/gconfd.c:391
 #, c-format
 msgid ""
 "Received signal %d, shutting down abnormally. Please file a GConf bug report."
 msgstr ""
 
-#: gconf/gconfd.c:409
+#: gconf/gconfd.c:408
 #, c-format
 msgid "Received signal %d, shutting down cleanly"
 msgstr ""
 
 #. openlog() does not copy logname - what total brokenness.
 #. So we free it at the end of main()
-#: gconf/gconfd.c:513
+#: gconf/gconfd.c:524
 #, c-format
 msgid "starting (version %s), pid %u user '%s'"
 msgstr ""
 
-#: gconf/gconfd.c:540
-msgid ""
-"Failed to init Object Activation Framework: please mail bug report to OAF "
-"maintainers"
-msgstr ""
-
-#: gconf/gconfd.c:560
+#: gconf/gconfd.c:565
 msgid "Failed to get object reference for ConfigServer"
 msgstr ""
 
-#: gconf/gconfd.c:573
-#, c-format
-msgid "Failed to create %s: %s"
-msgstr ""
-
-#. Bad hack alert - register the current lockholder with oafd,
-#. * since oafd seems to have forgotten about us.
-#.
-#: gconf/gconfd.c:588
-#, c-format
-msgid "Failed to get lock for daemon: %s"
-msgstr ""
-
-#: gconf/gconfd.c:594
-msgid ""
-"Registering existing server with oafd, since OAF appears to have leaked it"
-msgstr ""
-
 #: gconf/gconfd.c:603
-msgid ""
-"OAF doesn't know about our IID; indicates broken installation; can't "
-"register existing server."
-msgstr ""
-
-#: gconf/gconfd.c:607
-msgid ""
-"Another gconfd already registered with OAF, so we can't register the "
-"existing server"
-msgstr ""
-
-#: gconf/gconfd.c:612
-msgid "Unknown error registering existing gconfd with OAF; exiting"
-msgstr ""
-
-#: gconf/gconfd.c:639
-msgid ""
-"OAF doesn't know about our IID; indicates broken installation; can't "
-"register; exiting\n"
-msgstr ""
-
-#: gconf/gconfd.c:643
-msgid "Another gconfd already registered with OAF; exiting\n"
-msgstr ""
-
-#: gconf/gconfd.c:648
-msgid "Unknown error registering gconfd with OAF; exiting\n"
-msgstr ""
-
-#: gconf/gconfd.c:692
 #, c-format
-msgid "Failed to release lockfile: %s"
+msgid "Failed to write byte to pipe fd %d so client program may hang: %s"
 msgstr ""
 
-#: gconf/gconfd.c:700
+#: gconf/gconfd.c:613
+#, c-format
+msgid "Failed to get lock for daemon, exiting: %s"
+msgstr ""
+
+#: gconf/gconfd.c:655
+#, c-format
+msgid "Error releasing lockfile: %s"
+msgstr ""
+
+#: gconf/gconfd.c:663
 msgid "Exiting"
 msgstr ""
 
-#: gconf/gconfd.c:725
+#: gconf/gconfd.c:688
 msgid "GConf server is not in use, shutting down."
 msgstr ""
 
-#: gconf/gconfd.c:1084
+#: gconf/gconfd.c:1047
 #, c-format
 msgid "Returning exception: %s"
 msgstr ""
 
-#: gconf/gconfd.c:1184
+#: gconf/gconfd.c:1147
 #, c-format
 msgid ""
 "Failed to open gconfd logfile; won't be able to restore listeners after "
 "gconfd shutdown (%s)"
 msgstr ""
 
-#: gconf/gconfd.c:1219
+#: gconf/gconfd.c:1182
 #, c-format
 msgid ""
 "Failed to close gconfd logfile; data may not have been properly saved (%s)"
 msgstr ""
 
-#: gconf/gconfd.c:1288
+#: gconf/gconfd.c:1251
 #, c-format
 msgid "Could not open saved state file '%s' for writing: %s"
 msgstr ""
 
-#: gconf/gconfd.c:1302
+#: gconf/gconfd.c:1265
 #, c-format
 msgid "Could not write saved state file '%s' fd: %d: %s"
 msgstr ""
 
-#: gconf/gconfd.c:1311
+#: gconf/gconfd.c:1274
 #, c-format
 msgid "Failed to close new saved state file '%s': %s"
 msgstr ""
 
-#: gconf/gconfd.c:1325
+#: gconf/gconfd.c:1288
 #, c-format
 msgid "Could not move aside old saved state file '%s': %s"
 msgstr ""
 
-#: gconf/gconfd.c:1335
+#: gconf/gconfd.c:1298
 #, c-format
 msgid "Failed to move new save state file into place: %s"
 msgstr ""
 
-#: gconf/gconfd.c:1344
+#: gconf/gconfd.c:1307
 #, c-format
 msgid ""
 "Failed to restore original saved state file that had been moved to '%s': %s"
 msgstr ""
 
-#: gconf/gconfd.c:1819
+#: gconf/gconfd.c:1782
 #, c-format
 msgid ""
 "Unable to restore a listener on address '%s', couldn't resolve the database"
 msgstr ""
 
-#: gconf/gconfd.c:1865
+#: gconf/gconfd.c:1828
 #, c-format
 msgid "Error reading saved state file: %s"
 msgstr ""
 
-#: gconf/gconfd.c:1918
+#: gconf/gconfd.c:1881
 #, c-format
 msgid "Unable to open saved state file '%s': %s"
 msgstr ""
 
-#: gconf/gconfd.c:2035
+#: gconf/gconfd.c:1998
 #, c-format
 msgid ""
 "Failed to log addition of listener to gconfd logfile; won't be able to re-"
 "add the listener if gconfd exits or shuts down (%s)"
 msgstr ""
 
-#: gconf/gconfd.c:2040
+#: gconf/gconfd.c:2003
 #, c-format
 msgid ""
 "Failed to log removal of listener to gconfd logfile; might erroneously re-"
 "add the listener if gconfd exits or shuts down (%s)"
 msgstr ""
 
-#: gconf/gconfd.c:2063 gconf/gconfd.c:2228
+#: gconf/gconfd.c:2026 gconf/gconfd.c:2191
 #, c-format
 msgid "Failed to get IOR for client: %s"
 msgstr ""
 
-#: gconf/gconfd.c:2078
+#: gconf/gconfd.c:2041
 #, c-format
 msgid "Failed to open saved state file: %s"
 msgstr ""
 
-#: gconf/gconfd.c:2091
+#: gconf/gconfd.c:2054
 #, c-format
 msgid "Failed to write client add to saved state file: %s"
 msgstr ""
 
-#: gconf/gconfd.c:2099
+#: gconf/gconfd.c:2062
 #, c-format
 msgid "Failed to flush client add to saved state file: %s"
 msgstr ""
 
-#: gconf/gconfd.c:2189
+#: gconf/gconfd.c:2152
 msgid ""
 "Some client removed itself from the GConf server when it hadn't been added."
 msgstr ""
@@ -1291,403 +1328,392 @@ msgstr ""
 msgid "Must set the GCONF_CONFIG_SOURCE environment variable\n"
 msgstr ""
 
-#. Eventually you should be able to run gconfd as long as
-#. you're installing to a different database from the one
-#. it's using, but I don't trust the locking right now.
-#: gconf/gconftool.c:565
-msgid ""
-"Shouldn't run gconfd while installing new schema files.\n"
-"Use gconftool --shutdown to shut down the daemon, most safely while no "
-"applications are running\n"
-"(though things theoretically work if apps are running).\n"
-msgstr ""
-
-#: gconf/gconftool.c:587
+#: gconf/gconftool.c:576
 #, c-format
 msgid "Failed to access configuration source(s): %s\n"
 msgstr ""
 
-#: gconf/gconftool.c:798
+#: gconf/gconftool.c:787
 #, c-format
 msgid "Shutdown error: %s\n"
 msgstr ""
 
-#: gconf/gconftool.c:841
+#: gconf/gconftool.c:830
 msgid "Must specify one or more dirs to recursively list.\n"
 msgstr ""
 
-#: gconf/gconftool.c:875
+#: gconf/gconftool.c:864
 #, c-format
 msgid "Failure listing entries in `%s': %s\n"
 msgstr ""
 
-#: gconf/gconftool.c:893
+#: gconf/gconftool.c:882
 msgid "(no value set)"
 msgstr ""
 
-#: gconf/gconftool.c:948
+#: gconf/gconftool.c:937
 #, c-format
 msgid "Failed to spawn the config server (gconfd): %s\n"
 msgstr ""
 
-#: gconf/gconftool.c:962
+#: gconf/gconftool.c:951
 msgid "Must specify a key or keys to get\n"
 msgstr ""
 
-#: gconf/gconftool.c:997
+#: gconf/gconftool.c:986
 #, c-format
 msgid "Type: %s\n"
 msgstr ""
 
-#: gconf/gconftool.c:998
+#: gconf/gconftool.c:987
 #, c-format
 msgid "List Type: %s\n"
 msgstr ""
 
-#: gconf/gconftool.c:999
+#: gconf/gconftool.c:988
 #, c-format
 msgid "Car Type: %s\n"
 msgstr ""
 
-#: gconf/gconftool.c:1000
+#: gconf/gconftool.c:989
 #, c-format
 msgid "Cdr Type: %s\n"
 msgstr ""
 
-#: gconf/gconftool.c:1005
+#: gconf/gconftool.c:994
 #, c-format
 msgid "Default Value: %s\n"
 msgstr ""
 
-#: gconf/gconftool.c:1005 gconf/gconftool.c:1007 gconf/gconftool.c:1008
-#: gconf/gconftool.c:1009
+#: gconf/gconftool.c:994 gconf/gconftool.c:996 gconf/gconftool.c:997
+#: gconf/gconftool.c:998
 msgid "Unset"
 msgstr ""
 
-#: gconf/gconftool.c:1007
+#: gconf/gconftool.c:996
 #, c-format
 msgid "Owner: %s\n"
 msgstr ""
 
-#: gconf/gconftool.c:1008
+#: gconf/gconftool.c:997
 #, c-format
 msgid "Short Desc: %s\n"
 msgstr ""
 
-#: gconf/gconftool.c:1009
+#: gconf/gconftool.c:998
 #, c-format
 msgid "Long Desc: %s\n"
 msgstr ""
 
-#: gconf/gconftool.c:1018 gconf/gconftool.c:1312
+#: gconf/gconftool.c:1007 gconf/gconftool.c:1301
 #, c-format
 msgid "No value set for `%s'\n"
 msgstr ""
 
-#: gconf/gconftool.c:1022 gconf/gconftool.c:1316
+#: gconf/gconftool.c:1011 gconf/gconftool.c:1305
 #, c-format
 msgid "Failed to get value for `%s': %s\n"
 msgstr ""
 
-#: gconf/gconftool.c:1065 gconf/gconftool.c:1077
+#: gconf/gconftool.c:1054 gconf/gconftool.c:1066
 #, c-format
 msgid "Don't understand type `%s'\n"
 msgstr ""
 
-#: gconf/gconftool.c:1089
+#: gconf/gconftool.c:1078
 msgid "Must specify alternating keys/values as arguments\n"
 msgstr ""
 
-#: gconf/gconftool.c:1109
+#: gconf/gconftool.c:1098
 #, c-format
 msgid "No value to set for key: `%s'\n"
 msgstr ""
 
-#: gconf/gconftool.c:1137
+#: gconf/gconftool.c:1126
 msgid "Cannot set schema as value\n"
 msgstr ""
 
-#: gconf/gconftool.c:1147
+#: gconf/gconftool.c:1136
 msgid "When setting a list you must specify a primitive list-type\n"
 msgstr ""
 
-#: gconf/gconftool.c:1161
+#: gconf/gconftool.c:1150
 msgid ""
 "When setting a pair you must specify a primitive car-type and cdr-type\n"
 msgstr ""
 
-#: gconf/gconftool.c:1176
+#: gconf/gconftool.c:1165
 #, c-format
 msgid "Error: %s\n"
 msgstr ""
 
-#: gconf/gconftool.c:1189
+#: gconf/gconftool.c:1178
 #, c-format
 msgid "Error setting value: %s\n"
 msgstr ""
 
-#: gconf/gconftool.c:1207
+#: gconf/gconftool.c:1196
 #, c-format
 msgid "Error syncing: %s\n"
 msgstr ""
 
-#: gconf/gconftool.c:1230
+#: gconf/gconftool.c:1219
 msgid "Must specify a key or keys on the command line\n"
 msgstr ""
 
-#: gconf/gconftool.c:1250
+#: gconf/gconftool.c:1239
 #, c-format
 msgid "No schema known for `%s'\n"
 msgstr ""
 
-#: gconf/gconftool.c:1283
+#: gconf/gconftool.c:1272
 #, c-format
 msgid "No doc string stored in schema at '%s'\n"
 msgstr ""
 
-#: gconf/gconftool.c:1288
+#: gconf/gconftool.c:1277
 #, c-format
 msgid "Error getting schema at '%s': %s\n"
 msgstr ""
 
-#: gconf/gconftool.c:1295
+#: gconf/gconftool.c:1284
 #, c-format
 msgid "No schema stored at '%s'\n"
 msgstr ""
 
-#: gconf/gconftool.c:1298
+#: gconf/gconftool.c:1287
 #, c-format
 msgid "Value at '%s' is not a schema\n"
 msgstr ""
 
-#: gconf/gconftool.c:1354
+#: gconf/gconftool.c:1343
 msgid "Must specify a schema name followed by the key name to apply it to\n"
 msgstr ""
 
-#: gconf/gconftool.c:1361
+#: gconf/gconftool.c:1350
 #, c-format
 msgid "Error associating schema name '%s' with key name '%s': %s\n"
 msgstr ""
 
-#: gconf/gconftool.c:1381
+#: gconf/gconftool.c:1370
 msgid "Must specify key (schema name) as the only argument\n"
 msgstr ""
 
-#: gconf/gconftool.c:1423
+#: gconf/gconftool.c:1412
 msgid "List type must be a primitive type: string, int, float or bool\n"
 msgstr ""
 
-#: gconf/gconftool.c:1443
+#: gconf/gconftool.c:1432
 msgid "Pair car type must be a primitive type: string, int, float or bool\n"
 msgstr ""
 
-#: gconf/gconftool.c:1463
+#: gconf/gconftool.c:1452
 msgid "Pair cdr type must be a primitive type: string, int, float or bool\n"
 msgstr ""
 
-#: gconf/gconftool.c:1478
+#: gconf/gconftool.c:1467
 #, c-format
 msgid "Error setting value: %s"
 msgstr ""
 
-#: gconf/gconftool.c:1492
+#: gconf/gconftool.c:1481
 #, c-format
 msgid "Error syncing: %s"
 msgstr ""
 
-#: gconf/gconftool.c:1507
+#: gconf/gconftool.c:1496
 msgid "Must specify one or more dirs to get key/value pairs from.\n"
 msgstr ""
 
-#: gconf/gconftool.c:1521
+#: gconf/gconftool.c:1510
 msgid "Must specify one or more keys to unset.\n"
 msgstr ""
 
-#: gconf/gconftool.c:1532
+#: gconf/gconftool.c:1521
 #, c-format
 msgid "Error unsetting `%s': %s\n"
 msgstr ""
 
-#: gconf/gconftool.c:1555
+#: gconf/gconftool.c:1544
 msgid "Must specify one or more dirs to get subdirs from.\n"
 msgstr ""
 
-#: gconf/gconftool.c:1589
+#: gconf/gconftool.c:1578
 #, c-format
 msgid "Error listing dirs: %s\n"
 msgstr ""
 
-#: gconf/gconftool.c:1631
+#: gconf/gconftool.c:1620
 #, c-format
 msgid "WARNING: invalid or missing type for schema (%s)\n"
 msgstr ""
 
-#: gconf/gconftool.c:1640
+#: gconf/gconftool.c:1629
 #, c-format
 msgid "WARNING: invalid or missing list_type for schema (%s)\n"
 msgstr ""
 
-#: gconf/gconftool.c:1651 gconf/gconftool.c:1681 gconf/gconftool.c:1710
+#: gconf/gconftool.c:1640 gconf/gconftool.c:1670 gconf/gconftool.c:1699
 #, c-format
 msgid "WARNING: Failed to parse default value `%s' for schema (%s)\n"
 msgstr ""
 
-#: gconf/gconftool.c:1669
+#: gconf/gconftool.c:1658
 #, c-format
 msgid "WARNING: invalid or missing car_type or cdr_type for schema (%s)\n"
 msgstr ""
 
-#: gconf/gconftool.c:1694
+#: gconf/gconftool.c:1683
 msgid "WARNING: You cannot set a default value for a schema\n"
 msgstr ""
 
-#: gconf/gconftool.c:1723
+#: gconf/gconftool.c:1712
 msgid "WARNING: gconftool internal error, unknown GConfValueType\n"
 msgstr ""
 
-#: gconf/gconftool.c:1770 gconf/gconftool.c:1791 gconf/gconftool.c:1812
-#: gconf/gconftool.c:1833
+#: gconf/gconftool.c:1759 gconf/gconftool.c:1780 gconf/gconftool.c:1801
+#: gconf/gconftool.c:1822
 #, c-format
 msgid "WARNING: failed to parse type name `%s'\n"
 msgstr ""
 
-#: gconf/gconftool.c:1787
+#: gconf/gconftool.c:1776
 #, c-format
 msgid ""
 "WARNING: list_type can only be int, float, string or bool and not `%s'\n"
 msgstr ""
 
-#: gconf/gconftool.c:1808
+#: gconf/gconftool.c:1797
 #, c-format
 msgid "WARNING: car_type can only be int, float, string or bool and not `%s'\n"
 msgstr ""
 
-#: gconf/gconftool.c:1829
+#: gconf/gconftool.c:1818
 #, c-format
 msgid "WARNING: cdr_type can only be int, float, string or bool and not `%s'\n"
 msgstr ""
 
-#: gconf/gconftool.c:1857
+#: gconf/gconftool.c:1846
 msgid "WARNING: empty <applyto> node"
 msgstr ""
 
-#: gconf/gconftool.c:1860 gconf/gconftool.c:2123
+#: gconf/gconftool.c:1849 gconf/gconftool.c:2112
 #, c-format
 msgid "WARNING: node <%s> not understood below <schema>\n"
 msgstr ""
 
-#: gconf/gconftool.c:1870
+#: gconf/gconftool.c:1859
 msgid "WARNING: no key specified for schema\n"
 msgstr ""
 
-#: gconf/gconftool.c:1903
+#: gconf/gconftool.c:1892
 msgid "WARNING: <locale> node has no `name=\"locale\"' attribute, ignoring\n"
 msgstr ""
 
-#: gconf/gconftool.c:1909
+#: gconf/gconftool.c:1898
 #, c-format
 msgid ""
 "WARNING: multiple <locale> nodes for locale `%s', ignoring all past first\n"
 msgstr ""
 
-#: gconf/gconftool.c:1990
+#: gconf/gconftool.c:1979
 #, c-format
 msgid "WARNING: Invalid node <%s> in a <locale> node\n"
 msgstr ""
 
-#: gconf/gconftool.c:2019
+#: gconf/gconftool.c:2008
 #, c-format
 msgid "WARNING: failed to install schema `%s' locale `%s': %s\n"
 msgstr ""
 
-#: gconf/gconftool.c:2027
+#: gconf/gconftool.c:2016
 #, c-format
 msgid "Installed schema `%s' for locale `%s'\n"
 msgstr ""
 
-#: gconf/gconftool.c:2049
+#: gconf/gconftool.c:2038
 #, c-format
 msgid "WARNING: failed to associate schema `%s' with key `%s': %s\n"
 msgstr ""
 
-#: gconf/gconftool.c:2057
+#: gconf/gconftool.c:2046
 #, c-format
 msgid "Attached schema `%s' to key `%s'\n"
 msgstr ""
 
-#: gconf/gconftool.c:2136
+#: gconf/gconftool.c:2125
 msgid "You must have at least one <locale> entry in a <schema>\n"
 msgstr ""
 
-#: gconf/gconftool.c:2165
+#: gconf/gconftool.c:2154
 #, c-format
 msgid "WARNING: node <%s> not understood below <schemalist>\n"
 msgstr ""
 
-#: gconf/gconftool.c:2187
+#: gconf/gconftool.c:2176
 #, c-format
 msgid "Failed to open `%s': %s\n"
 msgstr ""
 
-#: gconf/gconftool.c:2194
+#: gconf/gconftool.c:2183
 #, c-format
 msgid "Document `%s' is empty?\n"
 msgstr ""
 
-#: gconf/gconftool.c:2206
+#: gconf/gconftool.c:2195
 #, c-format
 msgid ""
 "Document `%s' has the wrong type of root node (<%s>, should be "
 "<gconfschemafile>)\n"
 msgstr ""
 
-#: gconf/gconftool.c:2219
+#: gconf/gconftool.c:2208
 #, c-format
 msgid "Document `%s' has no top level <gconfschemafile> node\n"
 msgstr ""
 
-#: gconf/gconftool.c:2233
+#: gconf/gconftool.c:2222
 #, c-format
 msgid "WARNING: node <%s> below <gconfschemafile> not understood\n"
 msgstr ""
 
-#: gconf/gconftool.c:2244 gconf/gconftool.c:2276
+#: gconf/gconftool.c:2233 gconf/gconftool.c:2265
 #, c-format
 msgid "Error syncing config data: %s"
 msgstr ""
 
-#: gconf/gconftool.c:2260
+#: gconf/gconftool.c:2249
 msgid "Must specify some schema files to install\n"
 msgstr ""
 
-#: gconf/gconftool.c:2297
+#: gconf/gconftool.c:2286
 #, c-format
 msgid ""
 "\n"
 "%s\n"
 msgstr ""
 
-#: gconf/gconftool.c:2317
+#: gconf/gconftool.c:2306
 #, c-format
 msgid "Failed to unset breakage key %s: %s\n"
 msgstr ""
 
-#: gconf/gconftool.c:2443
+#: gconf/gconftool.c:2432
 msgid "Must specify some keys to break\n"
 msgstr ""
 
-#: gconf/gconftool.c:2449
+#: gconf/gconftool.c:2438
 #, c-format
 msgid ""
 "Trying to break your application by setting bad values for key:\n"
 "  %s\n"
 msgstr ""
 
-#: gconf/gconftool.c:2467
+#: gconf/gconftool.c:2456
 msgid "Must specify some directories to break\n"
 msgstr ""
 
-#: gconf/gconftool.c:2486
+#: gconf/gconftool.c:2475
 #, c-format
 msgid ""
 "Trying to break your application by setting bad values for keys in "
